@@ -1,19 +1,19 @@
-import numpy as np
-
 from ._single_layer_model import SingleLayerModel
 from ._classifier import Classifier
 from . import _functions
 
+
 class LogisticRegression(SingleLayerModel, Classifier):
     '''
     Implements logistic regression for classification.
     '''
+
     def __init__(self, input_size, output_size, reg_param=0):
         # Initialize base class
         super(LogisticRegression, self).__init__(input_size, output_size, reg_param)
 
         # Choose output activation function
-        if(output_size == 1):
+        if output_size == 1:
             # For binary classification
             self._afunc = _functions.sigmoid
             self._afunc_prime = _functions.sigmoid_prime
@@ -36,4 +36,4 @@ class LogisticRegression(SingleLayerModel, Classifier):
 
     @property
     def _cost_func_prime(self):
-        return _functions.cross_entropy_prime
\ No newline at end of file
+        return _functions.cross_entropy_prime
